@@ -10,8 +10,8 @@ pub enum ArgcValue {
     PositionalSingle(String, String),
     PositionalSingleFn(String, String),
     PositionalMultiple(String, Vec<String>),
-    CmdFnName(String),
-    ParamFnName(String),
+    CmdFn(String),
+    ParamFn(String),
 }
 
 impl ArgcValue {
@@ -71,18 +71,22 @@ impl ArgcValue {
                     ));
                     positional_args.extend(values);
                 }
-                ArgcValue::CmdFnName(name) => {
+                ArgcValue::CmdFn(name) => {
                     if positional_args.is_empty() {
                         variables.push(name.to_string());
                     } else {
                         variables.push(format!("{} {}", name, positional_args.join(" ")));
                     }
                 }
-                ArgcValue::ParamFnName(name) => {
+                ArgcValue::ParamFn(name) => {
                     variables.push(format!("{name};exit;"));
                 }
             }
         }
         variables.join("\n")
     }
+
+    pub fn is_cmd_fn(&self) -> bool {
+        matches!(self, Self::CmdFn(_))
+    }
 }
