@@ -47,6 +47,19 @@ pub enum EventData {
     Unknown(String),
 }
 
+#[derive(PartialEq, Eq)]
+pub enum EventScope {
+    Root,
+    CmdStart,
+    FnEnd,
+}
+
+impl Default for EventScope {
+    fn default() -> Self {
+        Self::Root
+    }
+}
+
 /// Tokenize shell script
 pub fn parse(source: &str) -> Result<Vec<Event>> {
     let mut result = vec![];
@@ -217,13 +230,24 @@ fn parse_flag_param(input: &str) -> nom::IResult<&str, FlagParam> {
     map(
         tuple((
             parse_short,
-            preceded(pair(space0, tag("--")), parse_param_name),
+            preceded(pair(space0, tag("--")), parse_param_multiple),
             parse_tail,
         )),
         |(short, arg, summary)| FlagParam::new(arg, summary, short),
     )(input)
 }
 
+// Parse `str*` `str`
+fn parse_param_multiple(input: &str) -> nom::IResult<&str, ParamData> {
+    alt((
+        map(terminated(parse_param_name, tag("*")), |mut arg| {
+            arg.multiple = true;
+            arg
+        }),
+        parse_param_name,
+    ))(input)
+}
+
 // Parse `str!` `str*` `str+` `str`
 fn parse_param_mark(input: &str) -> nom::IResult<&str, ParamData> {
     alt((
