@@ -1,5 +1,5 @@
 # @describe Test all aspects
-# @version    0.10
+# @version    0.10.0
 # @author     nobody <nobody@example.com>
 # @cmd Preferred
 # @arg        arg1*            A positional arg
@@ -60,6 +60,7 @@ cmd_option_quotes() {
 # @flag   -a --foo2    
 # @flag      --foo3     With description
 # @flag   -b --foo4     With description
+# @flag   -c --foo5*    Can occure multiple times
 cmd_flag_formats() {
     print_argc_vars
 }
@@ -138,6 +139,39 @@ cmd_with_hyphens() {
     print_argc_vars
 }
 
+# @cmd Nested command
+# @version 0.1.0
+# @option --opt1
+cmd_nested_command() {
+    print_argc_vars
+}
+
+# @cmd Subcommand of nested command
+# @option --opt1
+# @option --opt2
+cmd_nested_command::foo() {
+    print_argc_vars
+}
+
+# @cmd Nested command2
+# @version 0.1.0
+# @option --opt1
+cmd_nested_command2() {
+    :;
+}
+
+# @cmd Subcommand of nested command2
+# @option --opt1
+# @option --opt2
+cmd_nested_command2::foo() {
+    print_argc_vars
+}
+
+
+cmd_nested_command2::main() {
+    print_argc_vars
+}
+
 print_argc_vars() {
     ( set -o posix ; set ) | grep argc_
 }
